# Using and Analyzing Executive KPIs
### On this page
  * [KPI Status](https://help.sap.com/docs/leanix/ea/kpi-insights#kpi-status)
  * [KPI Drilldowns](https://help.sap.com/docs/leanix/ea/kpi-insights#kpi-drilldowns)
  * [KPI Breakdown](https://help.sap.com/docs/leanix/ea/kpi-insights#kpi-breakdown)
  * [Data Insights](https://help.sap.com/docs/leanix/ea/kpi-insights#data-insights)
  * [KPI Description and Calculation Logic](https://help.sap.com/docs/leanix/ea/kpi-insights#kpi-description-and-calculation-logic)


Gain insights from KPIs on the architecture executive dashboard to delve into data on your organization’s IT landscape.
The architecture executive dashboard provides predefined KPIs designed according to best-practice metrics for effective enterprise architecture management. These KPIs help you understand the performance of your IT landscape and identify areas for improvement. For a complete list of available KPIs for each use case, visit [Executive KPIs](https://help.sap.com/docs/leanix/ea/executive-kpis?locale=en-US&state=PRODUCTION&version=CLOUD "Explore the KPIs available on the architecture executive dashboard.").
To learn how to navigate the dashboard and gain insights step by step, visit [Navigating the Architecture Executive Dashboard](https://help.sap.com/docs/leanix/ea/navigate-architecture-executive-dashboard?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how data on the dashboard is structured and how to navigate the dashboard to gain insights.").
